@@ -319,16 +319,16 @@ Py_dcheb(PyObject *self, PyObject *args)
   if (not_doublevector(py_fnu)) return NULL;
 
   int nd = 1;
-  int dims[2];
+  npy_intp *dims = new npy_intp[2];
   dims[0] = n;
   // PyArray to C
   a = pyvector_to_Carrayptrs(py_a);
   b = pyvector_to_Carrayptrs(py_b);
   fnu = pyvector_to_Carrayptrs(py_fnu);
   // Allocate output variables
-  py_alpha = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
-  py_beta = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
-  py_s = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
+  py_alpha = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
+  py_beta = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
+  py_s = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
   alpha = pyvector_to_Carrayptrs(py_alpha);
   beta = pyvector_to_Carrayptrs(py_beta);
   s = pyvector_to_Carrayptrs(py_s);
@@ -368,14 +368,14 @@ Py_dchri(PyObject *self, PyObject *args)
   if (not_doublevector(py_b)) return NULL;
 
   int nd = 1;
-  int dims[2];
+  npy_intp *dims = new npy_intp[2];
   dims[0] = n;
   // PyArray to C
   a = pyvector_to_Carrayptrs(py_a);
   b = pyvector_to_Carrayptrs(py_b);
   // Allocate output variables
-  py_alpha = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
-  py_beta = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
+  py_alpha = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
+  py_beta = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
   alpha = pyvector_to_Carrayptrs(py_alpha);
   beta = pyvector_to_Carrayptrs(py_beta);
   
@@ -411,14 +411,14 @@ Py_dgauss(PyObject *self, PyObject *args)
   if (not_doublevector(py_b)) return NULL;
 
   int nd = 1;
-  int dims[2];
+  npy_intp *dims = new npy_intp[2];
   dims[0] = n;
   // PyArray to C
   a = pyvector_to_Carrayptrs(py_a);
   b = pyvector_to_Carrayptrs(py_b);
   // Allocate output variables
-  py_zero = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
-  py_weight = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
+  py_zero = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
+  py_weight = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
   zero = pyvector_to_Carrayptrs(py_zero);
   weight = pyvector_to_Carrayptrs(py_weight);
   // Allocate internal variables
@@ -466,14 +466,14 @@ Py_dgchri(PyObject *self, PyObject *args)
   if (not_doublevector(py_b)) return NULL;
 
   int nd = 1;
-  int dims[2];
+  npy_intp *dims = new npy_intp[2];
   dims[0] = n;
   // PyArray to C
   a = pyvector_to_Carrayptrs(py_a);
   b = pyvector_to_Carrayptrs(py_b);
   // Allocate output variables
-  py_alpha = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
-  py_beta = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
+  py_alpha = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
+  py_beta = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
   alpha = pyvector_to_Carrayptrs(py_alpha);
   beta = pyvector_to_Carrayptrs(py_beta);
   // Allocate internal variables
@@ -517,14 +517,14 @@ Py_dlancz(PyObject *self, PyObject *args)
   if (not_doublevector(py_y)) return NULL;
 
   int nd = 1;
-  int dims[2];
+  npy_intp *dims = new npy_intp[2];
   dims[0] = n;
   // PyArray to C
   x = pyvector_to_Carrayptrs(py_x);
   y = pyvector_to_Carrayptrs(py_y);
   // Allocate output variables
-  py_alpha = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
-  py_beta = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
+  py_alpha = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
+  py_beta = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
   alpha = pyvector_to_Carrayptrs(py_alpha);
   beta = pyvector_to_Carrayptrs(py_beta);
   // Allocate internal variables
@@ -565,14 +565,14 @@ Py_dlob(PyObject *self, PyObject *args)
   if (not_doublevector(py_beta)) return NULL;
 
   int nd = 1;
-  int dims[2];
+  npy_intp *dims = new npy_intp[2];
   dims[0] = n+2;
   // PyArray to C
   alpha = pyvector_to_Carrayptrs(py_alpha);
   beta = pyvector_to_Carrayptrs(py_beta);
   // Allocate output variables
-  py_zero = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
-  py_weight = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
+  py_zero = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
+  py_weight = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
   zero = pyvector_to_Carrayptrs(py_zero);
   weight = pyvector_to_Carrayptrs(py_weight);
   // Allocate internal variables
@@ -644,7 +644,7 @@ Py_dmcheb(PyObject *self, PyObject *args)
   if (not_doublevector(py_fnu)) return NULL;
 
   int nd = 1;
-  int dims[2];
+  npy_intp *dims = new npy_intp[2];
   dims[0] = n;
   // Set callback functions
   if (iq == 1) set_dquad_callback(self,Py_BuildValue("(O)",py_callback_func));
@@ -658,8 +658,8 @@ Py_dmcheb(PyObject *self, PyObject *args)
   b = pyvector_to_Carrayptrs(py_b);
   fnu = pyvector_to_Carrayptrs(py_fnu);
   // Allocate output variables
-  py_alpha = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
-  py_beta = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
+  py_alpha = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
+  py_beta = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
   alpha = pyvector_to_Carrayptrs(py_alpha);
   beta = pyvector_to_Carrayptrs(py_beta);
   // Allocate internal variables
@@ -729,7 +729,7 @@ Py_dmcdis(PyObject *self, PyObject *args)
   if (not_doublevector(py_endr)) return NULL;
 
   int nd = 1;
-  int dims[2];
+  npy_intp *dims = new npy_intp[2];
   dims[0] = n;
   // Set callback functions
   if (iq == 1) set_dquad_callback(self,Py_BuildValue("(O)",py_callback_func));
@@ -740,8 +740,8 @@ Py_dmcdis(PyObject *self, PyObject *args)
   endl = pyvector_to_Carrayptrs(py_endl);
   endr = pyvector_to_Carrayptrs(py_endr);
   // Allocate output variables
-  py_alpha = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
-  py_beta = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
+  py_alpha = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
+  py_beta = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
   alpha = pyvector_to_Carrayptrs(py_alpha);
   beta = pyvector_to_Carrayptrs(py_beta);
   // Allocate internal variables
@@ -790,14 +790,14 @@ Py_dradau(PyObject *self, PyObject *args)
   if (not_doublevector(py_beta)) return NULL;
 
   int nd = 1;
-  int dims[2];
+  npy_intp *dims = new npy_intp[2];
   dims[0] = n+2;
   // PyArray to C
   alpha = pyvector_to_Carrayptrs(py_alpha);
   beta = pyvector_to_Carrayptrs(py_beta);
   // Allocate output variables
-  py_zero = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
-  py_weight = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
+  py_zero = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
+  py_weight = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
   zero = pyvector_to_Carrayptrs(py_zero);
   weight = pyvector_to_Carrayptrs(py_weight);
   // Allocate internal variables
@@ -827,10 +827,10 @@ Py_drecur(PyObject *self, PyObject *args)
 
   // OUTPUT
   int nd = 1;
-  int dims[2];
+  npy_intp *dims = new npy_intp[2];
   dims[0] = n;
-  alpha = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
-  beta = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
+  alpha = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
+  beta = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
   a = pyvector_to_Carrayptrs(alpha);
   b = pyvector_to_Carrayptrs(beta);
   int ierr;
@@ -868,14 +868,14 @@ Py_dsti(PyObject *self, PyObject *args)
   if (not_doublevector(py_y)) return NULL;
 
   int nd = 1;
-  int dims[2];
+  npy_intp *dims = new npy_intp[2];
   dims[0] = n;
   // PyArray to C
   x = pyvector_to_Carrayptrs(py_x);
   y = pyvector_to_Carrayptrs(py_y);
   // Allocate output variables
-  py_alpha = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
-  py_beta = (PyArrayObject*) PyArray_FromDims(nd, dims, NPY_DOUBLE);
+  py_alpha = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
+  py_beta = (PyArrayObject*) PyArray_SimpleNew(nd, dims, NPY_DOUBLE);
   alpha = pyvector_to_Carrayptrs(py_alpha);
   beta = pyvector_to_Carrayptrs(py_beta);
   // Allocate internal variables
@@ -1015,7 +1015,7 @@ Py_polyeval(PyObject *self, PyObject *args)
   PyArrayObject *py_out;
   double *out;
   // INTERNAL
-  int *dims = new int[1];
+  npy_intp *dims = new npy_intp[1];
   double *old1, *old2, *outinner, *tmp, *nrmpol, *nrmold1, *nrmold2;
   double *zeros, *weights, *e;
 
@@ -1040,7 +1040,7 @@ Py_polyeval(PyObject *self, PyObject *args)
   beta = pyvector_to_Carrayptrs(py_beta);
 
   // Allocate output variables
-  py_out = (PyArrayObject*) PyArray_FromDims(1, dims, NPY_DOUBLE);
+  py_out = (PyArrayObject*) PyArray_SimpleNew(1, dims, NPY_DOUBLE);
   out = pyvector_to_Carrayptrs(py_out);
   // Allocate auxiliary space
   outinner = new double[dims[0]];
@@ -1132,7 +1132,7 @@ Py_vandermonde(PyObject *self, PyObject *args)
   PyArrayObject *py_out;
   double **out;
   // INTERNAL
-  int *dims = new int[2];
+  npy_intp *dims = new npy_intp[2];
   double **nrmpol;
   double *zeros, *weights, *e;
 
@@ -1158,7 +1158,7 @@ Py_vandermonde(PyObject *self, PyObject *args)
   beta = pyvector_to_Carrayptrs(py_beta);
 
   // Allocate output variables
-  py_out = (PyArrayObject*) PyArray_FromDims(2, dims, NPY_DOUBLE);
+  py_out = (PyArrayObject*) PyArray_SimpleNew(2, dims, NPY_DOUBLE);
   out = pymatrix_to_Carrayptrs(py_out);
 
   // Internal normalization variables
